/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.allgemein;

/**
 * Die mglichen RDS-Ereignisse
 * 
 * @author Dambach Werke
 * @version $Revision: 1.3 $ / $Date: 2009/01/27 13:54:22 $ / ($Author: Sans $)
 */
public enum RDSEreignis
{
  KEINE_AUSSAGE(1, "keine Aussage"),
  DICHTER_VERKEHR(2, "dichter Verkehr"),
  STOCKENDER_VERKEHR(3, "stockender Verkehr"),
  STAU(4, "Stau");

  /**
   * Numerische Darstellung des  Ereignisses
   */
  public final int id;
  
  /**
   * Text-Darstellung des  Ereignisses
   */
  public final String text;
  
  @Override
  public String toString()
  {
    return text;
  }
  
  /**
   * @param id Ereignis-Id
   * @return das zur bergebenen Ereignis-Id gehrende RDSEreignis oder null, 
   * falls es zur Id kein RDSEreignis gibt
   */
  public static RDSEreignis get(int id)
  {
    for (RDSEreignis ereignis: values())
    {
      if (ereignis.id == id)
      {
        return ereignis;
      }
    }
    return null;
  }
  
  /**
   * Privater Konstruktor
   */
  private RDSEreignis(int id, String text)
  {
    this.id = id;
    this.text = text;
  }
  
}