/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.junit.prueffall1;

import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import org.junit.Test;

import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.SystemObject;
import de.bsvrz.ste.rdstmc.junit.RDSTMCPrueffall;
import de.bsvrz.ste.rdstmc.junit.tools.WarteAufNeueUndAktualisierteDaten;
import de.bsvrz.ste.rdstmc.meldungserstellung.VerwaltungMeldungen;
import de.bsvrz.sys.funclib.debug.Debug;

/**
 * @author Sans
 *
 */
public class Prueffall1_2_200s extends RDSTMCPrueffall
{
  /**
   * Debug-Logger fr Logging-Ausgaben
   */
  private final static Debug _debug = Debug.getLogger();

  @Test
  public void testPrueffall_1_2_200s()throws Exception
  {
    assertTestGeneratorLaeuft();
    
    SystemObject meldung2 = getDataModel().getObject(VerwaltungMeldungen.PID_PREFIX + "2");
    assertNotNull("Objekt " + VerwaltungMeldungen.PID_PREFIX + "2" + " existiert", meldung2);
    String erwartetePid = VerwaltungMeldungen.PID_PREFIX + "3";

    WarteAufNeueUndAktualisierteDaten wanuad = new WarteAufNeueUndAktualisierteDaten(getConnection(),
        getMeldungsMenge(), new String[] { erwartetePid }, new SystemObject[] { meldung2 },
        getDataDescription(), 20000 + TOL_PLUS);
    
    ResultData rd2 = wanuad.getAktualisierteDaten().get(meldung2.getPid());
    ResultData rd3 = wanuad.getNeueDaten().get(erwartetePid);
    
    assertTrue("1 neues Objekt " + erwartetePid + " in der Menge " + 
        getMeldungsMenge().getName() + " wurde erzeugt",
        wanuad.getNeueDaten().size() == 1 && 
        rd3 != null && rd3.getObject().getPid().equals(erwartetePid));
    
    assertTrue("1 Meldungen " + meldung2.getPid() + " wurde aktualisiert",
        wanuad.getAktualisierteDaten().size() == 1 &&
        rd2 != null && rd2.getObject().equals(meldung2));
    
    assertPruefZeitKorrekt(200000, Math.max(rd2.getDataTime(), rd3.getDataTime()));
    
    assertMeldungsDatenKorrekt(rd2,
        InformationsTyp.ALERTC,
        MeldungsArt.AKTUALISIERUNG,
        GeografischeBedeutung.NATIONAL,
        ZeitlicheDringlichkeit.NORMAL,
        ZeitlicheDauer.UNBEKANNT,
        -1,
        103,
        11907,
        null,
        null);
    
    assertMeldungsDatenKorrekt(rd3,
        InformationsTyp.ALERTC,
        MeldungsArt.AKTUALISIERUNG,
        GeografischeBedeutung.NATIONAL,
        ZeitlicheDringlichkeit.NORMAL,
        ZeitlicheDauer.UNBEKANNT,
        -1,
        131,
        11906,
        null,
        null);
  }
}
