/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.junit.tools;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.Data.Array;

public class ResultWrapper 
{
  private ResultData _resultData;
  
  public ResultWrapper(ResultData resultData)
  {
    _resultData = resultData;
  }

  public int getInformationsTyp()
  {
    Data data = getVerkehrsData().getItem("Ereignis").getItem("EreignisKodierung");
    return data.asUnscaledValue().intValue();
  }
  
  public String getMeldungsArt()
  {
    Data data = getVerwaltungsData().getItem("Status"); 
    return data.asTextValue().getText();
  }
  
  public int getGeografischeBedeutung()
  {
    Data data = getVerkehrsData().getItem("ZusatzAttribute").getItem("GeographischeRelevanz");
    return data.asUnscaledValue().intValue();
  }
  
  public int getZeitlicheDringlichkeit()
  {
    Data data = getVerwaltungsData().getItem("Prioritt"); 
    return data.asUnscaledValue().intValue();
  }
  
  public int getZeitlicheDauer()
  {
    Array array = getVerkehrsData().getItem("Ereignis").getArray("EreignisDaten");
    Data data = array.getItem(0).getItem("EreignisDauer"); 
    return data.asUnscaledValue().intValue();
  }
  
  public int getAusmassRichtung()
  {
    Data data = getVerkehrsData().getItem("LocationDaten");
    int extent = data.getItem("LocationExtent").asUnscaledValue().intValue();
    String richtung = data.getItem("TMCRichtung").asTextValue().getText();
    if (richtung.equals("Positiv"))
    {
      return extent;
    }
    else if (richtung.equals("Negativ"))
    {
      return extent * (-1);
    }
    else
    {
      throw new IllegalStateException("Richtung ist undefiniert");
    }
  }
  
  public int getEreignisCode()
  {
    Array array = getVerkehrsData().getItem("Ereignis").getArray("EreignisDaten");
    Data data = array.getItem(0).getItem("EreignisCode"); 
    return data.asUnscaledValue().intValue();
  }
  
  public int getPrimaereLocation()
  {
    Array array = getVerkehrsData().getItem("LocationDaten").getArray("RDSLocation");
    Data data = array.getItem(0).getItem("LocationCode"); 
    return data.asUnscaledValue().intValue();
  }
  
  public String getOptionalWert(String optionalKennung)
  {
    String result = null;
    
    Array array = getVerkehrsData().getItem("Ereignis").getArray("EreignisDaten");
    Array eqArray = array.getItem(0).getArray("EreignisQuantitt");
    if (eqArray != null)
    {
      for (int i = 0; i < eqArray.getLength(); i += 1)
      {
        String kennung = eqArray.getItem(i).getItem("QuantittsKennung").asReferenceValue().getSystemObjectPid();
        if (kennung.equals(optionalKennung))
        {
          result = eqArray.getItem(i).getItem("QuantittsWert").asTextValue().getText();
          break;  
        }
      }
    }
    
    return result;
  }
  
  private Data getVersionsData(Data data)
  {
    return data.getItem("Version");
  }
  
  private Data getVerwaltungsData()
  {
    return getVersionsData(_resultData.getData()).getItem("VerwaltungsInformationen");
  }
  
  private Data getVerkehrsData()
  {
    return getVersionsData(_resultData.getData()).getItem("VerkehrsInformationen");
  }
  
}
