/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.ste.rdstmc.junit.tools;

import java.util.Map;

import de.bsvrz.dav.daf.main.ClientDavInterface;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.ResultData;
import de.bsvrz.dav.daf.main.config.MutableSet;
import de.bsvrz.dav.daf.main.config.SystemObject;

public class WarteAufNeueUndAktualisierteDaten
{
  private WarteAufNeueDaten _wand;
  private WarteAufAktualisierteDaten _waad;
    
  public Map<String, ResultData> getNeueDaten()
  {
    return _wand.getNeueDaten();
  }
  public Map<String, ResultData> getAktualisierteDaten()
  {
    return _waad.getAktualisierteDaten();
  }
  
  private ClientDavInterface _connection;
  private MutableSet _menge; 
  private String[] _erwartetePids;
  private SystemObject[] _objekte;
  private DataDescription _dd;
  private long _timeout;
  
  private class NeueDaten extends Thread
  {
    public void run()
    {
      _wand = new WarteAufNeueDaten(_connection, _menge, _erwartetePids, _dd, _timeout);
    }  
  }
  
  private class AktualisierteDaten extends Thread
  {
    public void run()
    {
      _waad = new WarteAufAktualisierteDaten(_connection, _menge, _objekte, _dd, _timeout);
    }  
  }  
  
  /**
   * Es werden die neu in einer Menge hinzukommenden Objekte bestimmt, sowie die Aktualisierungen 
   * gltiger Datenstze aller vorhandenen Objekte in der Menge. Auf neue Objekte und Aktualisiereungen 
   * wird gewartet, bis alle erwarteten neuen Objekte in der Menge sind und alle Objekte, fr die 
   * Aktualisierungen erwartet werden, aktualisiert sind,  oder bis ein Timeout verstrichen ist.
   * 
   * @param connection die DAV-Verbindung
   * @param menge die Menge, deren Objekte berwacht wird
   * @param erwartetePids die PIDs der Objekte, von denen erwartet wird, dass sie neu in die Menge
   * hinzukommen 
   * @param objekte die Objekte, fr die Aktualisiereungen erwartet werden
   * @param dd Datenbeschreibung der erwarteten neuen und aktualisierten Datenstze
   * @param timeout Timeout - solange wird maximal auf neue oder aktualisierte gltige Daten fr 
   * alle Objekte gewartet - wird hier 0 bergeben, wird unendlich lange gewartet (dead lock Gefahr)
   */
  public WarteAufNeueUndAktualisierteDaten(ClientDavInterface connection, MutableSet menge, 
      String[] erwartetePids, SystemObject[] objekte, DataDescription dd, long timeout)
  {
    _connection = connection;
    _menge = menge;
    _erwartetePids = erwartetePids;
    _objekte = objekte;
    _dd = dd;
    _timeout = timeout;
    
    Thread neueDaten = new NeueDaten();
    Thread aktualisierteDaten = new AktualisierteDaten(); 
    
    neueDaten.start();
    aktualisierteDaten.start();
    
    try
    {
      neueDaten.join();
      aktualisierteDaten.join();
    }
    catch(InterruptedException e)
    {
      throw new RuntimeException("Unerwarteter Abbruch", e);
    }
  }
  
  
}
